@@ -71,7 +71,7 @@ def plot_cv_snr(raw_df, file_name, output_path, sfreq=None,
     bins : int, optional
         直方图分箱数，默认40
     """
-    from ..tests.raw_quality import raw_CV, raw_SNR
+    from ..nirs_preprocess.raw_quality import raw_CV, raw_SNR
     from ..utils.helper import get_sfreq
     
     # 获取采样率
@@ -222,7 +222,7 @@ def plot_quality_comparison(raw_df, file_name, output_path,
     snr_threshold : float, optional
         SNR阈值，默认15
     """
-    from ..tests.raw_quality import raw_CV, raw_SNR
+    from ..nirs_preprocess.raw_quality import raw_CV, raw_SNR
     from ..utils.helper import extract_channel_id
     
     # 计算质量指标
@@ -430,7 +430,7 @@ def plot_quality_violin(raw_df, file_name, output_path, group_by_wavelength=True
     group_by_wavelength : bool, optional
         是否按波长分组，默认True
     """
-    from ..tests.raw_quality import raw_CV, raw_SNR
+    from ..nirs_preprocess.raw_quality import raw_CV, raw_SNR
     from ..utils.helper import extract_channel_id
     
     # 计算质量指标
